==============
 Renga v0.1.0
==============

Renga v0.1.0 was released on TBD, 2017.

About
-----

Python SDK and CLI for the Renga platform.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install renga==0.1.0

Documentation
-------------

   https://renga.readthedocs.io/

Happy hacking and thanks for flying Renga.

| Swiss Data Science Center Development Team
|   Email: contact@datascience.ch
|   Twitter: https://twitter.com/SDSCdatascience
|   GitHub: https://github.com/SwissDataScienceCenter/renga-python
|   URL: http://datascience.ch
